@@ -192,6 +192,9 @@ gst_rmdemux_get_type (void)
   return rmdemux_type;
 }
 
+GST_ELEMENT_REGISTER_DEFINE (rmdemux, "rmdemux",
+    GST_RANK_PRIMARY, GST_TYPE_RMDEMUX);
+
 static void
 gst_rmdemux_base_init (GstRMDemuxClass * klass)
 {
@@ -2667,10 +2670,3 @@ not_enough_data:
     return GST_FLOW_OK;
   }
 }
-
-gboolean
-gst_rmdemux_plugin_init (GstPlugin * plugin)
-{
-  return gst_element_register (plugin, "rmdemux",
-      GST_RANK_PRIMARY, GST_TYPE_RMDEMUX);
-}
